![BSD 3-clause](https://img.shields.io/badge/license-BSD%203--clause-blue.svg)
[![Build Status](https://travis-ci.com/metricq/metricq.svg?branch=master)](https://travis-ci.com/metricq/metricq)
![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)
[![PyPI](https://img.shields.io/pypi/v/metricq)](https://pypi.org/project/metricq/)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/metricq)
# metricq
